pyspread Manual

# Manual

© Martin Manns

## What is pyspread about?

Not too long ago, I wrote a small decision support system for engineers in a spreadsheet application that we all know too well. Because the calculations should be transparent, everything was realized with the in-cell functions. It works now. However, the length and complexity of the cell commands keep the application pretty opaque.
Therefore, I looked for a spreadsheet with more powerful functions and data structures that are accessible inside each cell. Something like Python that empowers you to do things quickly. And yes, it should be free and it should run on Linux as well as on Windows. I looked around and found nothing that suited me. Therefore, I started pyspread.

## Concept

- Each cell accepts any input that works in a Python command line.
- The inputs are parsed and evaluated by Python's eval command.
- The result objects are accessible via a 3D numpy object array.
- String representations of the result objects are displayed in the cells.

## Benefits

- Each cell returns a Python object. This object can be anything including arrays and third party library objects.
- Generator expressions can be used efficiently for data manipulation.
- Efficient numpy slicing is used.
- numpy methods are accessible for the data.